@@ -168,7 +168,7 @@ def test_compress_numpy():
     frames = dumps({'x': to_serialize(x)})
     assert sum(map(nbytes, frames)) < x.nbytes
 
-    header = msgpack.loads(frames[2], encoding='utf8', use_list=False)
+    header = msgpack.loads(frames[2], raw=False, use_list=False)
     try:
         import blosc  # noqa: F401
     except ImportError:
